@@ -69,20 +69,19 @@ def run(
 
     main_df = MONGO_HANDLE.data(countries, indicator_codes, years,
                                 callback=callback, index_freq=index_freq, country_freq=country_freq)
-    results = table_from_frame(main_df)
 
+    results = table_from_frame(main_df)
     results = AggregationMethods.aggregate(results, years, agg_method if len(years) > 1 else 0)
 
-    # Add descriptions to indicators
+    #Add descriptions to indicators
     for attrib in results.domain.attributes:
-        for (db, code, desc, ind_exp, is_rel, url) in indicators:
+        for (db, code, desc, ind_exp, is_rel, url, *_) in indicators:
             if len(ind_exp) > 0:
                 if code in attrib.name:
                     split = code.split(".")
                     attrib.attributes["Description"] = desc
-                    for i in range(len(split)):
-                        attrib.attributes[EXP_NAMES[i]] = f"{split[i]} - {ind_exp[i]}"
-
+                    for i in range(len(ind_exp)):
+                        attrib.attributes[EXP_NAMES[min(i, len(EXP_NAMES)-1)]] = f"{split[i]} - {ind_exp[i]}"
     return results
 
 
@@ -300,6 +299,7 @@ class IndicatorFilterProxyModel(QSortFilterProxyModel):
     def __init__(self):
         super(IndicatorFilterProxyModel, self).__init__()
         self.rel_only = False
+        self.rem_sparse = False
         self.and_filter = False
         self._filter_string = ""
 
@@ -311,6 +311,10 @@ class IndicatorFilterProxyModel(QSortFilterProxyModel):
         self.rel_only = x
         self.invalidateFilter()
 
+    def set_sparse(self, x):
+        self.rem_sparse = x
+        self.invalidateFilter()
+
     def set_and_filter(self):
         self.and_filter = not self.and_filter
         self.invalidateFilter()
@@ -332,7 +336,9 @@ class IndicatorFilterProxyModel(QSortFilterProxyModel):
 
     def filterAcceptsRow(self, source_row, source_parent):
         row = self.sourceModel()[source_row]
-        return self.filter_accepts_row(row) and (not self.rel_only or (self.rel_only and row[4]))
+        return self.filter_accepts_row(row) and \
+               (not self.rel_only or (self.rel_only and row[4])) and \
+               (not self.rem_sparse or (self.rem_sparse and not row[6]))
 
     def sort(self, column: int, order: Qt.SortOrder = Qt.AscendingOrder):
         super().sort(column, order)
@@ -389,21 +395,21 @@ class OWWHStudy(OWWidget, ConcurrentWidgetMixin):
         vbox.layout().addLayout(grid)
         spin_box = gui.vBox(vbox, "Indicator frequency (%)")
         grid.addWidget(spin_box, alignment=Qt.AlignLeft)
-        spin_box.setFixedWidth(grid.sizeHint().width())
+        spin_box.setFixedWidth(175)
         gui.spin(spin_box, self, 'indicator_freq', minv=1, maxv=100,
                  callback=self.__on_dummy_change,
                  tooltip="Percentage of received values to keep indicator."
                  )
         cspin_box = gui.vBox(vbox, "Country frequency (%)")
         grid.addWidget(cspin_box, alignment=Qt.AlignLeft)
-        cspin_box.setFixedWidth(grid.sizeHint().width())
+        cspin_box.setFixedWidth(175)
         gui.spin(cspin_box, self, 'country_freq', minv=1, maxv=100,
                  callback=self.__on_dummy_change,
                  tooltip="Percentage of received values to keep country.")
 
         agg_box = gui.vBox(vbox, "Aggreagtion by year")
         grid.addWidget(agg_box, alignment=Qt.AlignLeft)
-        agg_box.setFixedWidth(grid.sizeHint().width())
+        agg_box.setFixedWidth(175)
         gui.comboBox(agg_box, self, 'agg_method', items=AggregationMethods.ITEMS,
                      callback=self.__on_dummy_change)
 
@@ -438,6 +444,13 @@ class OWWHStudy(OWWidget, ConcurrentWidgetMixin):
             self.__on_indicator_relative_changed
         )
 
+        self.__indicator_sparse_checkbox = QCheckBox("Remove Sparse", self)
+        self.__indicator_sparse_checkbox.setToolTip("Remove very sparse indicators.")
+        self.__indicator_sparse_checkbox.setChecked(False)
+        self.__indicator_sparse_checkbox.stateChanged.connect(
+            self.__on_indicator_relative_changed
+        )
+
         self.__indicator_and_button = gui.button(box, self, "Any", width=50, callback=self.__on_indicator_filter_changed)
         self.__indicator_and_button.adjustSize()
         self.__indicator_and_button.setToolTip("Toggle filtering indicators that include all words.")
@@ -446,6 +459,7 @@ class OWWHStudy(OWWidget, ConcurrentWidgetMixin):
         filters_row.layout().addWidget(self.__indicator_filter_line_edit)
         filters_row.layout().addWidget(self.__indicator_and_button)
         filters_row.layout().addWidget(self.__indicator_relative_checkbox)
+        filters_row.layout().addWidget(self.__indicator_sparse_checkbox)
         available_box.layout().addWidget(filters_row)
 
         def dropcompleted(action):
@@ -511,6 +525,7 @@ class OWWHStudy(OWWidget, ConcurrentWidgetMixin):
     def __on_indicator_relative_changed(self):
         model = self.available_indices_view.model()
         model.set_rel(self.__indicator_relative_checkbox.isChecked())
+        model.set_sparse(self.__indicator_sparse_checkbox.isChecked())
         self._select_indicator_rows()
 
     def __on_indicator_delete(self, key):
